@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2010-2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2010-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -17,7 +17,7 @@
 import os, sys, re, time
 from calculate.lib.encrypt import encrypt
 from os import path
-from calculate.lib.utils.files import pathJoin
+from calculate.lib.utils.files import pathJoin, FilePermission
 
 from calculate.lib.cl_lang import setLocalTranslate, _
 
@@ -472,12 +472,13 @@ class migrate(object):
         """Create home directories for all migreate users"""
 
         def createHome(userdata):
+            perms = FilePermission.UserAll
             if not userdata[5].startswith('/dev/'):
                 homedir = pathJoin(self.prefixNewSystem, userdata[5])
                 if not path.exists(homedir):
                     os.mkdir(homedir)
                     os.chown(homedir, int(userdata[2]), int(userdata[3]))
-
+                    os.chmod(homedir, perms)
         users = list(
             set(map(lambda x: x[0],
                     addUsersList) + existsMigrateUsers) - {"root"})
